@@ -1,8 +1,9 @@
 # vim: ts=4:sw=4:expandtab
+# coding=utf-8
 
 # BleachBit
-# Copyright (C) 2008-2015 Andrew Ziem
-# http://bleachbit.sourceforge.net
+# Copyright (C) 2008-2016 Andrew Ziem
+# http://www.bleachbit.org
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -45,12 +46,15 @@ def _action_str_to_commands(action_str):
 
 
 def _action_str_to_results(action_str):
-    """Parse <action> and return list of results"""
+    """Parse <action> and return list of results
+
+    It lists the files, but it does not really delete them.
+    """
     return [cmd.execute(False).next() for cmd in _action_str_to_commands(action_str)]
 
 
-def benchmark_regex():
-    """Measure how fast the regex option is"""
+def benchmark_filter(this_filter):
+    """Measure how fast listing files is with and without filter"""
     n_files = 100000
     print 'benchmark of %d files' % n_files
 
@@ -62,12 +66,19 @@ def benchmark_regex():
     # scan directory
     import time
     start = time.time()
-    action_str = '<action command="delete" search="glob" path="%s/*" regex="^12$"/>' % dirname
+    filter_code = ''
+    if 'regex' == this_filter:
+        # This regex matches everything, so the "no filter" and regex
+        # are comparable
+        filter_code = 'regex="."'
+    action_str = '<action command="delete" search="glob" path="%s/*" %s />' % \
+        (dirname, filter_code)
     results = _action_str_to_results(action_str)
     end = time.time()
     elapsed_seconds = end - start
     rate = n_files / elapsed_seconds
-    print 'elapsed: %.2f seconds, %.2f files/second' % (elapsed_seconds, rate)
+    print 'filter %s: elapsed: %.2f seconds, %.2f files/second' % (this_filter,
+                                                                   elapsed_seconds, rate)
 
     # clean up
     shutil.rmtree(dirname)
@@ -80,7 +91,7 @@ def dir_is_empty(dirname):
     return not os.listdir(dirname)
 
 
-class ActionTestCase(unittest.TestCase):
+class ActionTestCase(unittest.TestCase, common.AssertFile):
 
     """Test cases for Action"""
 
@@ -98,8 +109,10 @@ class ActionTestCase(unittest.TestCase):
         self.assertNotEqual(provider, None)
         for cmd in provider.get_commands():
             self.assert_(
-                isinstance(cmd, (Command.Delete, Command.Ini, Command.Json)))
-            self.assert_(os.path.lexists(filename))
+                isinstance(cmd, (Command.Delete, Command.Ini, Command.Json, Command.Function)))
+            if 'process' != command:
+                # process does not have a filename
+                self.assertLExists(filename)
             # preview
             result = cmd.execute(really_delete=False).next()
             common.validate_result(self, result)
@@ -107,14 +120,15 @@ class ActionTestCase(unittest.TestCase):
             # delete
             ret = cmd.execute(really_delete=True).next()
             if 'delete' == command:
-                self.assert_(not os.path.lexists(cmd.path),
-                             'exists: %s' % cmd.path)
+                self.assertNotLExists(cmd.path)
             elif 'truncate' == command:
-                self.assert_(os.path.lexists(filename))
+                self.assertLExists(filename)
                 os.remove(filename)
-                self.assert_(not os.path.lexists(filename))
+                self.assertNotLExists(filename)
+            elif command in ('process'):
+                pass
             elif command in ('ini', 'json'):
-                self.assert_(os.path.lexists(filename))
+                self.assertLExists(filename)
             else:
                 raise RuntimeError("Unknown command '%s'" % command)
         if 'walk.all' == search:
@@ -151,7 +165,23 @@ class ActionTestCase(unittest.TestCase):
                 action_str = '<action command="%s" search="file" path="%s" />' % \
                     (command, filename)
                 self._test_action_str(action_str)
-                self.assert_(not os.path.exists(filename))
+                self.assertNotExists(filename)
+
+    def test_delete_special_filenames(self):
+        """Unit test for deleting special filenames"""
+        dirname = tempfile.mkdtemp(prefix='bleachbit-action-delete-special')
+        tests = [
+            'normal',
+            'space in name',
+            'sigil$should-not-be-expanded',
+        ]
+        for test in tests:
+            pathname = os.path.join(dirname, test)
+            common.touch_file(pathname)
+            action_str = '<action command="delete" search="file" path="%s" />' % pathname
+            self._test_action_str(action_str)
+            self.assertNotExists(pathname)
+        os.rmdir(dirname)
 
     def test_ini(self):
         """Unit test for class Ini"""
@@ -178,6 +208,17 @@ class ActionTestCase(unittest.TestCase):
 
         test_json_helper(self, execute_json)
 
+    def test_process(self):
+        """Unit test for process action"""
+        tests = ['<action command="process" cmd="dir" />',
+                 '<action command="process" wait="false" cmd="dir" />',
+                 '<action command="process" wait="f" cmd="dir" />',
+                 '<action command="process" wait="no" cmd="dir" />',
+                 '<action command="process" wait="n" cmd="dir" />']
+
+        for test in tests:
+            self._test_action_str(test)
+
     def test_regex(self):
         """Unit test for regex option"""
         _iglob = glob.iglob
@@ -196,6 +237,15 @@ class ActionTestCase(unittest.TestCase):
         self.assert_(1 == len(results))
         self.assertEqual(results[0]['path'], '/tmp/foo2')
 
+        # On Windows should be case insensitive
+        action_str = '<action command="delete" search="glob" path="/tmp/foo*" regex="^FOO2$"/>'
+        results = _action_str_to_results(action_str)
+        if 'nt' == os.name:
+            self.assert_(1 == len(results))
+            self.assertEqual(results[0]['path'], '/tmp/foo2')
+        else:
+            self.assert_(0 == len(results))
+
         # should match second file using negative regex
         action_str = '<action command="delete" search="glob" path="/tmp/foo*" nregex="^(foo1|bar1)$"/>'
         results = _action_str_to_results(action_str)
@@ -227,6 +277,66 @@ class ActionTestCase(unittest.TestCase):
         glob.iglob = _iglob
         FileUtilities.getsize = _getsize
 
+    def test_wholeregex(self):
+        """Unit test for wholeregex filter"""
+        _iglob = glob.iglob
+        glob.iglob = lambda x: ['/tmp/foo1', '/tmp/foo2', '/tmp/bar1']
+        _getsize = FileUtilities.getsize
+        FileUtilities.getsize = lambda x: 1
+
+        # should match three files using no regexes
+        action_str = '<action command="delete" search="glob" path="/tmp/foo*" />'
+        results = _action_str_to_results(action_str)
+        self.assert_(3 == len(results))
+
+        # should match two files using wholeregex
+        action_str = '<action command="delete" search="glob" path="/tmp/foo*" wholeregex="^/tmp/foo.*$"/>'
+        results = _action_str_to_results(action_str)
+        self.assert_(2 == len(results))
+        self.assertEqual(results[0]['path'], '/tmp/foo1')
+
+        # should match third file using nwholeregex
+        action_str = '<action command="delete" search="glob" path="/tmp/foo*" nwholeregex="^/tmp/foo.*$"/>'
+        results = _action_str_to_results(action_str)
+        self.assert_(1 == len(results))
+        self.assertEqual(results[0]['path'], '/tmp/bar1')
+
+        # clean up
+        glob.iglob = _iglob
+        FileUtilities.getsize = _getsize
+
+    def test_type(self):
+        """Unit test for type attribute"""
+        dirname = tempfile.mkdtemp(prefix='bleachbit-action-type')
+        filename = os.path.join(dirname, 'file')
+
+        # this should not delete anything
+        common.touch_file(filename)
+        action_str = '<action command="delete" search="file" type="d" path="%s" />' % filename
+        self._test_action_str(action_str)
+        self.assertExists(filename)
+
+        # should delete file
+        action_str = '<action command="delete" search="file" type="f" path="%s" />' % filename
+        self._test_action_str(action_str)
+        self.assertNotExists(filename)
+
+        # should delete file
+        common.touch_file(filename)
+        action_str = '<action command="delete" search="file" path="%s" />' % filename
+        self._test_action_str(action_str)
+        self.assertNotExists(filename)
+
+        # should not delete anything
+        action_str = '<action command="delete" search="file" type="f" path="%s" />' % dirname
+        self._test_action_str(action_str)
+        self.assertExists(dirname)
+
+        # should delete directory
+        action_str = '<action command="delete" search="file" type="d" path="%s" />' % dirname
+        self._test_action_str(action_str)
+        self.assertNotExists(dirname)
+
     def test_walk_all(self):
         """Unit test for walk.all"""
         dirname = tempfile.mkdtemp(prefix='bleachbit-walk-all')
@@ -234,15 +344,17 @@ class ActionTestCase(unittest.TestCase):
         # this sub-directory should be deleted
         subdir = os.path.join(dirname, 'sub')
         os.mkdir(subdir)
-        self.assert_(os.path.exists(subdir))
+        self.assertExists(subdir)
 
         # this file should be deleted too
         filename = os.path.join(subdir, 'file')
-        open(filename, 'a').close()
+        common.touch_file(filename)
 
         action_str = '<action command="delete" search="walk.all" path="%s" />' % dirname
         self._test_action_str(action_str)
-        self.assert_(not os.path.exists(subdir))
+        self.assertNotExists(subdir)
+
+        os.rmdir(dirname)
 
     def test_walk_files(self):
         """Unit test for walk.files"""
@@ -268,14 +380,16 @@ def suite():
 
 if __name__ == '__main__':
     if 1 < len(sys.argv) and 'benchmark' == sys.argv[1]:
-        rates = []
-        iterations = 1
-        if 3 == len(sys.argv):
-            iterations = int(sys.argv[2])
-        for x in xrange(0, iterations):
-            rate = benchmark_regex()
-            rates.append(rate)
-        # combine all the rates for easy copy and paste into R for analysis
-        print 'rates=%s' % ','.join([str(rate) for rate in rates])
+        for this_filter in ['none', 'regex']:
+            rates = []
+            iterations = 1
+            if 3 == len(sys.argv):
+                iterations = int(sys.argv[2])
+            for x in xrange(0, iterations):
+                rate = benchmark_filter(this_filter)
+                rates.append(rate)
+            # combine all the rates for easy copy and paste into R for analysis
+            print 'rates for filter %s=%s' % (this_filter,
+                                              ','.join([str(rate) for rate in rates]))
         sys.exit()
     unittest.main()
