@@ -1,8 +1,8 @@
 # vim: ts=4:sw=4:expandtab
 
 # BleachBit
-# Copyright (C) 2008-2015 Andrew Ziem
-# http://bleachbit.sourceforge.net
+# Copyright (C) 2008-2016 Andrew Ziem
+# http://www.bleachbit.org
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -32,7 +32,7 @@ from bleachbit.CleanerML import *
 import common
 
 
-class CleanerMLTestCase(unittest.TestCase):
+class CleanerMLTestCase(unittest.TestCase, common.AssertFile):
 
     """Test cases for CleanerML"""
 
@@ -75,7 +75,7 @@ class CleanerMLTestCase(unittest.TestCase):
     def test_list_cleanerml_files(self):
         """Unit test for list_cleanerml_files()"""
         for pathname in list_cleanerml_files():
-            self.assert_(os.path.exists(pathname))
+            self.assertExists(pathname)
 
     def test_load_cleaners(self):
         """Unit test for load_cleaners()"""
@@ -88,8 +88,9 @@ class CleanerMLTestCase(unittest.TestCase):
         Common.personal_cleaners_dir = tempfile.mkdtemp(
             prefix='bleachbit-cleanerml-load')
         fn_xml = os.path.join(Common.personal_cleaners_dir, 'invalid.xml')
-        with open(fn_xml, 'w') as f:
-            f.write('<xml><broken>')
+        f = open(fn_xml, 'w')
+        f.write('<xml><broken>')
+        f.close()
         load_cleaners()
         import shutil
         shutil.rmtree(Common.personal_cleaners_dir)
