@@ -2,8 +2,8 @@
 # -*- coding: UTF-8 -*-
 
 # BleachBit
-# Copyright (C) 2008-2015 Andrew Ziem
-# http://bleachbit.sourceforge.net
+# Copyright (C) 2008-2016 Andrew Ziem
+# http://www.bleachbit.org
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -278,7 +278,8 @@ class FileUtilitiesTestCase(unittest.TestCase):
                  (u'\u2014', 'em-dash'),  # LP#1454030
                  (hebrew, hebrew),
                  (katanana, katanana),
-                 (umlauts, umlauts)]
+                 (umlauts, umlauts),
+                 ('sigil', 'should$not-change')]
         if 'posix' == os.name:
             # Windows doesn't allow these characters but Unix systems do
             tests.append(('"', '*'))
@@ -664,7 +665,7 @@ class FileUtilitiesTestCase(unittest.TestCase):
     def test_wipe_name(self):
         """Unit test for wipe_name()"""
 
-         # create test file with moderately long name
+        # create test file with moderately long name
         (handle, filename) = tempfile.mkstemp(
             prefix="bleachbit-test-wipe" + "0" * 50)
         os.close(handle)
