@@ -1,8 +1,8 @@
 # vim: ts=4:sw=4:expandtab
 
 # BleachBit
-# Copyright (C) 2008-2015 Andrew Ziem
-# http://bleachbit.sourceforge.net
+# Copyright (C) 2008-2016 Andrew Ziem
+# http://www.bleachbit.org
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -100,7 +100,7 @@ class UpdateTestCase(unittest.TestCase):
             print 'note: deleting %s' % fn
             os.unlink(fn)
 
-        url = 'http://www.winapp2.com/Winapp2.ini'
+        url = 'http://katana.oooninja.com/bleachbit/winapp2/winapp2-2016-03-14.ini'
 
         def append_text(s):
             print s
@@ -111,11 +111,13 @@ class UpdateTestCase(unittest.TestCase):
             succeeded['r'] = True
 
         # bad hash
+        succeeded['r'] = False
         self.assertRaises(RuntimeError, update_winapp2, url, "notahash",
                           append_text, on_success)
         self.assert_(not succeeded['r'])
 
         # blank hash, download file
+        succeeded['r'] = False
         update_winapp2(url, None, append_text, on_success)
         self.assert_(succeeded['r'])
 
