@@ -2,8 +2,8 @@
 # -*- coding: UTF-8 -*-
 
 # BleachBit
-# Copyright (C) 2008-2015 Andrew Ziem
-# http://bleachbit.sourceforge.net
+# Copyright (C) 2008-2016 Andrew Ziem
+# http://www.bleachbit.org
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -53,7 +53,7 @@ def put_files_into_recycle_bin():
         move_to_recycle_bin(filename)
     # make a folder and move it to the recycle bin
     dirname = tempfile.mkdtemp(prefix='bleachbit-recycle-folder')
-    open(os.path.join(dirname, 'file'), 'a').close()
+    common.touch_file(os.path.join(dirname, 'file'))
     move_to_recycle_bin(dirname)
 
 
@@ -268,19 +268,19 @@ class WindowsTestCase(unittest.TestCase):
             self.assertEqual(expected_key, key)
 
     def test_start_with_computer(self):
-            """Unit test for start_with_computer*"""
-            b = start_with_computer_check()
-            self.assert_(isinstance(b, bool))
-            # opposite setting
-            start_with_computer(not b)
-            two_b = start_with_computer_check()
-            self.assert_(isinstance(two_b, bool))
-            self.assertEqual(b, not two_b)
-            # original setting
-            start_with_computer(b)
-            three_b = start_with_computer_check()
-            self.assert_(isinstance(b, bool))
-            self.assertEqual(b, three_b)
+        """Unit test for start_with_computer*"""
+        b = start_with_computer_check()
+        self.assert_(isinstance(b, bool))
+        # opposite setting
+        start_with_computer(not b)
+        two_b = start_with_computer_check()
+        self.assert_(isinstance(two_b, bool))
+        self.assertEqual(b, not two_b)
+        # original setting
+        start_with_computer(b)
+        three_b = start_with_computer_check()
+        self.assert_(isinstance(b, bool))
+        self.assertEqual(b, three_b)
 
     def test_parse_windows_build(self):
         """Unit test for parse_windows_build"""
