@@ -1,8 +1,8 @@
 # vim: ts=4:sw=4:expandtab
 
 # BleachBit
-# Copyright (C) 2008-2015 Andrew Ziem
-# http://bleachbit.sourceforge.net
+# Copyright (C) 2008-2016 Andrew Ziem
+# http://www.bleachbit.org
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -25,6 +25,40 @@ Common code for unit tests
 
 import os
 import types
+from bleachbit.FileUtilities import extended_path
+
+
+class AssertFile:
+
+    def getTestPath(self, path):
+        if 'nt' == os.name:
+            return extended_path(os.path.normpath(path))
+        return path
+
+    def assertExists(self, path, msg='', func=os.path.exists):
+        """File, directory, or any path exists"""
+        from bleachbit.FileUtilities import expandvars
+        path = expandvars(path)
+        if not func(self.getTestPath(path)):
+            raise AssertionError(
+                'The file %s should exist, but it does not. %s' % (path, msg))
+
+    def assertLExists(self, path, msg=''):
+        self.assertExists(path, msg, os.path.lexists)
+
+    def assertNotLExists(self, path, msg=''):
+        self.assertNotExists(path, msg, os.path.lexists)
+
+    def assertNotExists(self, path, msg='', func=os.path.exists):
+        if func(self.getTestPath(path)):
+            raise AssertionError(
+                'The file %s should not exist, but it does. %s' % (path, msg))
+
+    def assertCondExists(self, cond, path, msg=''):
+        if cond:
+            self.assertExists(path, msg)
+        else:
+            self.assertNotExists(path, msg)
 
 
 def destructive_tests(title):
@@ -39,6 +73,8 @@ def touch_file(filename):
     """Create an empty file"""
     f = open(filename, "w")
     f.close()
+    import os.path
+    assert(os.path.exists(filename))
 
 
 def validate_result(self, result, really_delete=False):
@@ -57,13 +93,15 @@ def validate_result(self, result, really_delete=False):
                  "size is %s" % str(result['size']))
     # path
     filename = result['path']
+    if not filename:
+        # the process action, for example, does not have a filename
+        return
+    from bleachbit.Common import encoding
     self.assert_(isinstance(filename, (str, unicode, type(None))),
-                 "Filename is invalid: '%s' (type %s)" % (str(filename), type(filename)))
+                 "Filename is invalid: '%s' (type %s)" % (filename.encode(encoding, 'replace'), type(filename)))
     if isinstance(filename, (str, unicode)) and \
             not filename[0:2] == 'HK':
         if really_delete:
-            self.assert_(not os.path.lexists(filename),
-                         "Path exists: '%s'" % (filename))
+            self.assertNotLExists(filename)
         else:
-            self.assert_(os.path.lexists(filename),
-                         "Path does not exist: '%s'" % (filename))
+            self.assertLExists(filename)
